@@ -1,8 +1,8 @@
 ##############################################################################
-#      $URL: http://perlcritic.tigris.org/svn/perlcritic/tags/Perl-Critic-1.053/lib/Perl/Critic/Config.pm $
-#     $Date: 2007-06-03 13:16:10 -0700 (Sun, 03 Jun 2007) $
+#      $URL: http://perlcritic.tigris.org/svn/perlcritic/tags/Perl-Critic-1.06/lib/Perl/Critic/Config.pm $
+#     $Date: 2007-06-27 23:50:20 -0700 (Wed, 27 Jun 2007) $
 #   $Author: thaljef $
-# $Revision: 1578 $
+# $Revision: 1709 $
 ##############################################################################
 
 package Perl::Critic::Config;
@@ -11,18 +11,21 @@ use strict;
 use warnings;
 use Carp qw(confess);
 use English qw(-no_match_vars);
+
 use List::MoreUtils qw(any none apply);
 use Scalar::Util qw(blessed);
+
+use Perl::Critic::ConfigErrors;
 use Perl::Critic::PolicyFactory;
-use Perl::Critic::Theme qw();
+use Perl::Critic::Theme qw( $RULE_INVALID_CHARACTER_REGEX &cook_rule );
 use Perl::Critic::UserProfile qw();
 use Perl::Critic::Utils qw{
-    :booleans :characters :severities :internal_lookup
+    :booleans :characters :severities :internal_lookup :classification
 };
 
 #-----------------------------------------------------------------------------
 
-our $VERSION = 1.053;
+our $VERSION = 1.06;
 
 #-----------------------------------------------------------------------------
 # Constructor
@@ -38,7 +41,6 @@ sub new {
 #-----------------------------------------------------------------------------
 
 sub _init {
-
     my ( $self, %args ) = @_;
 
     # -top or -theme imply that -severity is 1, unless it is already defined
@@ -46,43 +48,64 @@ sub _init {
         $args{-severity} ||= $SEVERITY_LOWEST;
     }
 
+    my $errors = Perl::Critic::ConfigErrors->new();
+
     # Construct the UserProfile to get default options.
-    my $p        = $args{-profile}; #Can be file path or data struct
-    my $profile  = Perl::Critic::UserProfile->new( -profile => $p );
+    my $profile_source  = $args{-profile}; #Can be file path or data struct
+    my $profile =
+        Perl::Critic::UserProfile->new( -profile => $profile_source );
     my $defaults = $profile->defaults();
     $self->{_profile} = $profile;
 
     # If given, these options should always have a true value.
-    $self->{_include}      = $args{-include}      || $defaults->include();
-    $self->{_exclude}      = $args{-exclude}      || $defaults->exclude();
-    $self->{_singlepolicy} = $args{-singlepolicy} || $defaults->singlepolicy();
-    $self->{_verbose}      = $args{-verbose}      || $defaults->verbose();
+    $self->_validate_and_save_regex(
+        'include', $args{-include}, $defaults->include(), $errors
+    );
+    $self->_validate_and_save_regex(
+        'exclude', $args{-exclude}, $defaults->exclude(), $errors
+    );
+    $self->_validate_and_save_regex(
+        'single-policy',
+        $args{'-single-policy'},
+        $defaults->single_policy(),
+        $errors,
+    );
 
-    # Severity levels can be expressed as names or numbers
-    my $severity        = $args{-severity} || $defaults->severity();
-    $self->{_severity}  = severity_to_number( $severity );
+    $self->_validate_and_save_verbosity($args{-verbose}, $errors);
+    $self->_validate_and_save_severity($args{-severity}, $errors);
+    $self->_validate_and_save_top($args{-top}, $errors);
 
     # If given, these options can be true or false (but defined)
     # We normalize these to numeric values by multiplying them by 1;
-    no warnings 'numeric'; ## no critic (ProhibitNoWarnings)
-    $self->{_top}   = 1 * _dor( $args{-top},   $defaults->top()   );
-    $self->{_force} = 1 * _dor( $args{-force}, $defaults->force() );
-    $self->{_only}  = 1 * _dor( $args{-only},  $defaults->only()  );
+    {
+        no warnings 'numeric'; ## no critic (ProhibitNoWarnings)
+        $self->{_force} = 1 * _dor( $args{-force}, $defaults->force() );
+        $self->{_only}  = 1 * _dor( $args{-only},  $defaults->only()  );
+        $self->{_color} = 1 * _dor( $args{-color}, $defaults->color() );
+        $self->{_strict_profile} =
+            1 * _dor( $args{'-strict-profile'}, $defaults->strict_profile() );
+    }
 
-    # Construct a Theme object from rule
-    my $theme_rule = $args{-theme} || $defaults->theme();
-    my $theme = Perl::Critic::Theme->new( -rule => $theme_rule );
-    $self->{_theme} = $theme;
+    $self->_validate_and_save_theme($args{-theme}, $errors);
 
     # Construct a Factory with the Profile
-    my $factory = Perl::Critic::PolicyFactory->new( -profile => $profile );
+    my $factory =
+        Perl::Critic::PolicyFactory->new(
+            -profile          => $profile,
+            -errors           => $errors,
+            '-strict-profile' => $self->strict_profile(),
+        );
     $self->{_factory} = $factory;
 
+    if ( @{ $errors->messages() } ) {
+        die $errors;  ## no critic (RequireCarping)
+    }
+
     # Initialize internal storage for Policies
     $self->{_policies} = [];
 
     # "NONE" means don't load any policies
-    return $self if defined $p and $p eq 'NONE';
+    return $self if defined $profile_source and $profile_source eq 'NONE';
 
     # Heavy lifting here...
     $self->_load_policies();
@@ -126,8 +149,8 @@ sub _load_policies {
 
     for my $policy ( @policies ) {
 
-        # If -singlepolicy is true, only load policies that match it
-        if ( $self->singlepolicy() ) {
+        # If -single-policy is true, only load policies that match it
+        if ( $self->single_policy() ) {
             if ( $self->_policy_is_single_policy( $policy ) ) {
                 $self->add_policy( -policy => $policy );
             }
@@ -150,19 +173,19 @@ sub _load_policies {
         $self->add_policy( -policy => $policy );
     }
 
-    # When using -singlepolicy, only one policy should ever be loaded.
-    if ($self->singlepolicy() && scalar $self->policies() != 1) {
+    # When using -single-policy, only one policy should ever be loaded.
+    if ($self->single_policy() && scalar $self->policies() != 1) {
         $self->_throw_single_policy_exception();
     }
 
-    return $self;
+    return;
 }
 
 #-----------------------------------------------------------------------------
 
 sub _policy_is_disabled {
     my ($self, $policy) = @_;
-    my $profile = $self->{_profile};
+    my $profile = $self->_profile();
     return $profile->policy_is_disabled( $policy );
 }
 
@@ -170,7 +193,7 @@ sub _policy_is_disabled {
 
 sub _policy_is_enabled {
     my ($self, $policy) = @_;
-    my $profile = $self->{_profile};
+    my $profile = $self->_profile();
     return $profile->policy_is_enabled( $policy );
 }
 
@@ -213,9 +236,12 @@ sub _policy_is_excluded {
 
 sub _policy_is_single_policy {
     my ($self, $policy) = @_;
+
+    my @patterns = $self->single_policy();
+    return if not @patterns;
+
     my $policy_long_name = ref $policy;
-    my $singlepolicy = $self->singlepolicy() || return;
-    return $policy_long_name =~ m/$singlepolicy/imx;
+    return any { $policy_long_name =~ m/$_/imx } @patterns;
 }
 
 #-----------------------------------------------------------------------------
@@ -225,17 +251,257 @@ sub _throw_single_policy_exception {
     my $self = shift;
 
     my $error_msg = $EMPTY;
-    my $sp_option = $self->singlepolicy();
+    my $patterns = join q{", "}, $self->single_policy();
 
     if (scalar $self->policies() == 0) {
-        $error_msg = qq{No policies matched "$sp_option".};
+        $error_msg =
+            qq{No policies matched any of "$patterns" (in combination with }
+                . q{other policy restrictions).};
     }
     else {
-        $error_msg  = qq{Multiple policies matched "$sp_option":\n\t};
+        $error_msg  = qq{Multiple policies matched "$patterns":\n\t};
         $error_msg .= join qq{,\n\t}, apply { chomp } sort $self->policies();
     }
 
-    die "$error_msg\n";
+    confess "$error_msg\n";
+}
+
+#-----------------------------------------------------------------------------
+
+sub _validate_and_save_regex {
+    my ($self, $option_name, $args_value, $default_value, $errors) = @_;
+
+    my $full_option_name;
+    my $source;
+    my @regexes;
+
+    if ($args_value) {
+        $full_option_name = "-$option_name";
+
+        if (ref $args_value) {
+            @regexes = @{ $args_value };
+        }
+        else {
+            @regexes = ( $args_value );
+        }
+    }
+
+    if (not @regexes) {
+        $full_option_name = $option_name;
+        $source = $self->_profile()->source();
+
+        if (ref $default_value) {
+            @regexes = @{ $default_value };
+        }
+        elsif ($default_value) {
+            @regexes = ( $default_value );
+        }
+    }
+
+    my $found_errors;
+    foreach my $regex (@regexes) {
+        eval { my $test = qr/$regex/imx; };
+        if ($EVAL_ERROR) {
+            (my $cleaned_error = $EVAL_ERROR) =~
+                s/ [ ] at [ ] .* Config [.] pm [ ] line [ ] \d+ [.] \n? \z/./xms;
+
+            $errors->add_bad_option_message(
+                $option_name,
+                $regex,
+                $source,
+                qq{is not valid: $cleaned_error},
+            );
+
+            $found_errors = 1;
+        }
+    }
+
+    if (not $found_errors) {
+        my $option_key = $option_name;
+        $option_key =~ s/ - /_/xmsg;
+
+        $self->{"_$option_key"} = \@regexes;
+    }
+
+    return;
+}
+
+#-----------------------------------------------------------------------------
+
+sub _validate_and_save_verbosity {
+    my ($self, $args_value, $errors) = @_;
+
+    my $option_name;
+    my $source;
+    my $verbosity;
+
+    if ($args_value) {
+        $option_name = '-verbose';
+        $verbosity = $args_value;
+    }
+    else {
+        $option_name = 'verbose';
+
+        my $profile = $self->_profile();
+        $source = $profile->source();
+        $verbosity = $profile->defaults()->verbose();
+    }
+
+    if ( is_integer($verbosity) and not is_valid_numeric_verbosity($verbosity) ) {
+        $errors->add_bad_option_message(
+            $option_name,
+            $verbosity,
+            $source,
+            'is not the number of one of the pre-defined verbosity formats.',
+        );
+    }
+    else {
+        $self->{_verbose} = $verbosity;
+    }
+
+    return;
+}
+
+#-----------------------------------------------------------------------------
+
+sub _validate_and_save_severity {
+    my ($self, $args_value, $errors) = @_;
+
+    my $option_name;
+    my $source;
+    my $severity;
+
+    if ($args_value) {
+        $option_name = '-severity';
+        $severity = $args_value;
+    }
+    else {
+        $option_name = 'severity';
+
+        my $profile = $self->_profile();
+        $source = $profile->source();
+        $severity = $profile->defaults()->severity();
+    }
+
+    if ( is_integer($severity) ) {
+        if (
+            $severity >= $SEVERITY_LOWEST and $severity <= $SEVERITY_HIGHEST
+        ) {
+            $self->{_severity} = $severity;
+        }
+        else {
+            $errors->add_bad_option_message(
+                $option_name,
+                $severity,
+                $source,
+                "is not between $SEVERITY_LOWEST (low) and $SEVERITY_HIGHEST (high).",
+            );
+        }
+    }
+    elsif ( not any { $_ eq lc $severity } @SEVERITY_NAMES ) {
+        $errors->add_bad_option_message(
+            $option_name,
+            $severity,
+            $source,
+            q{is not one of the valid severity names: "}
+                . join (q{", "}, @SEVERITY_NAMES)
+                . q{".},
+        );
+    }
+    else {
+        $self->{_severity} = severity_to_number($severity);
+    }
+
+    return;
+}
+
+#-----------------------------------------------------------------------------
+
+sub _validate_and_save_top {
+    my ($self, $args_value, $errors) = @_;
+
+    my $option_name;
+    my $source;
+    my $top;
+
+    if (defined $args_value and $args_value ne q{}) {
+        $option_name = '-top';
+        $top = $args_value;
+    }
+    else {
+        $option_name = 'top';
+
+        my $profile = $self->_profile();
+        $source = $profile->source();
+        $top = $profile->defaults()->top();
+    }
+
+    if ( is_integer($top) and $top >= 0 ) {
+        $self->{_top} = $top;
+    }
+    else {
+        $errors->add_bad_option_message(
+            $option_name,
+            $top,
+            $source,
+            q{is not a non-negative integer.},
+        );
+    }
+
+    return;
+}
+
+#-----------------------------------------------------------------------------
+
+sub _validate_and_save_theme {
+    my ($self, $args_value, $errors) = @_;
+
+    my $option_name;
+    my $source;
+    my $theme_rule;
+
+    if ($args_value) {
+        $option_name = '-theme';
+        $theme_rule = $args_value;
+    }
+    else {
+        $option_name = 'theme';
+
+        my $profile = $self->_profile();
+        $source = $profile->source();
+        $theme_rule = $profile->defaults()->theme();
+    }
+
+    if ( $theme_rule =~ m/$RULE_INVALID_CHARACTER_REGEX/xms ) {
+        my $bad_character = $1;
+
+        $errors->add_bad_option_message(
+            $option_name,
+            $theme_rule,
+            $source,
+            qq{contains an illegal character ("$bad_character").},
+        );
+    }
+    else {
+        my $rule_as_code = cook_rule($theme_rule);
+
+        $rule_as_code =~ s/ [\w\d]+ / 1 /gxms;
+        eval $rule_as_code;  ## no critic (ProhibitStringyEval)
+
+        if ($EVAL_ERROR) {
+            $errors->add_bad_option_message(
+                $option_name,
+                $theme_rule,
+                $source,
+                q{is not syntactically valid.},
+            );
+        }
+        else {
+            $self->{_theme} = Perl::Critic::Theme->new( -rule => $theme_rule );
+        }
+    }
+
+    return;
 }
 
 #-----------------------------------------------------------------------------
@@ -249,6 +515,13 @@ sub _dor {
 #-----------------------------------------------------------------------------
 # Begin ACCESSSOR methods
 
+sub _profile {
+    my $self = shift;
+    return $self->{_profile};
+}
+
+#-----------------------------------------------------------------------------
+
 sub policies {
     my $self = shift;
     return @{ $self->{_policies} };
@@ -284,6 +557,13 @@ sub only {
 
 #-----------------------------------------------------------------------------
 
+sub strict_profile {
+    my $self = shift;
+    return $self->{_strict_profile};
+}
+
+#-----------------------------------------------------------------------------
+
 sub severity {
     my $self = shift;
     return $self->{_severity};
@@ -291,9 +571,9 @@ sub severity {
 
 #-----------------------------------------------------------------------------
 
-sub singlepolicy {
+sub single_policy {
     my $self = shift;
-    return $self->{_singlepolicy};
+    return @{ $self->{_single_policy} };
 }
 
 #-----------------------------------------------------------------------------
@@ -319,6 +599,13 @@ sub verbose {
 
 #-----------------------------------------------------------------------------
 
+sub color {
+    my $self = shift;
+    return $self->{_color};
+}
+
+#-----------------------------------------------------------------------------
+
 sub site_policy_names {
     return Perl::Critic::PolicyFactory::site_policy_names();
 }
@@ -331,7 +618,7 @@ __END__
 
 =pod
 
-=for stopwords -params INI-style -singlepolicy
+=for stopwords -params INI-style
 
 =head1 NAME
 
@@ -350,7 +637,7 @@ constructor will do it for you.
 
 =over 8
 
-=item C<< new( [ -profile => $FILE, -severity => $N, -theme => $string, -include => \@PATTERNS, -exclude => \@PATTERNS, -singlepolicy => $PATTERN, -top => $N, -only => $B, -force => $B, -verbose => $N ] ) >>
+=item C<< new( [ -profile => $FILE, -severity => $N, -theme => $string, -include => \@PATTERNS, -exclude => \@PATTERNS, -single-policy => $PATTERN, -top => $N, -only => $B, -strict-profile => $B, -force => $B, -verbose => $N, -color => $B ] ) >>
 
 =item C<< new() >>
 
@@ -395,7 +682,7 @@ Config, irrespective of the severity settings.  You can use it in
 conjunction with the C<-include> option.  Note that C<-exclude> takes
 precedence over C<-include> when a Policy matches both patterns.
 
-B<-singlepolicy> is a string C<PATTERN>.  Only the policy that matches
+B<-single-policy> is a string C<PATTERN>.  Only the policy that matches
 C<m/$PATTERN/imx> will be used.  This value overrides the
 C<-severity>, C<-theme>, C<-include>, C<-exclude>, and C<-only>
 options.
@@ -411,6 +698,13 @@ will only choose from Policies that are mentioned in the user's
 profile.  If set to a false value (which is the default), then
 Perl::Critic chooses from all the Policies that it finds at your site.
 
+B<-strict-profile> is a boolean value.  If set to a true value,
+Perl::Critic will make certain warnings about problems found in a
+F<.perlcriticrc> or file specified via the B<-profile> option fatal.
+In particular, Perl::Critic normally only C<warn>s about profiles
+referring to non-existent Policies, but this option makes this
+situation fatal.
+
 B<-force> controls whether Perl::Critic observes the magical C<"## no
 critic"> pseudo-pragmas in your code.  If set to a true value,
 Perl::Critic will analyze all code.  If set to a false value (which is
@@ -421,6 +715,9 @@ B<-verbose> can be a positive integer (from 1 to 10), or a literal
 format specification.  See L<Perl::Critic::Violations> for an
 explanation of format specifications.
 
+B<-color> is not used by Perl::Critic but is provided for the benefit
+of L<perlcritic>.
+
 =back
 
 =head1 METHODS
@@ -464,13 +761,17 @@ Returns the value of the C<-force> attribute for this Config.
 
 Returns the value of the C<-only> attribute for this Config.
 
+=item C< strict_profile() >
+
+Returns the value of the C<-strict-profile> attribute for this Config.
+
 =item C< severity() >
 
 Returns the value of the C<-severity> attribute for this Config.
 
-=item C< singlepolicy() >
+=item C< single_policy() >
 
-Returns the value of the C<-singlepolicy> attribute for this Config.
+Returns the value of the C<-single-policy> attribute for this Config.
 
 =item C< theme() >
 
@@ -485,6 +786,10 @@ Returns the value of the C<-top> attribute for this Config.
 
 Returns the value of the C<-verbose> attribute for this Config.
 
+=item C< color() >
+
+Returns the value of the C<-color> attribute for this Config.
+
 =back
 
 =head1 SUBROUTINES
@@ -533,6 +838,7 @@ corresponding Perl::Critic constructor argument.
     theme     = risky + (pbp * security) - cosmetic   #A theme expression
     include   = NamingConventions ClassHierarchies    #Space-delimited list
     exclude   = Variables  Modules::RequirePackage    #Space-delimited list
+    color     = 1                                     #Zero or One
 
 The remainder of the configuration file is a series of blocks like
 this:
