@@ -1,34 +1,32 @@
+##############################################################################
+#      $URL: http://perlcritic.tigris.org/svn/perlcritic/tags/Perl-Critic-1.06/lib/Perl/Critic/Policy/ValuesAndExpressions/ProhibitLongChainsOfMethodCalls.pm $
+#     $Date: 2007-06-27 23:50:20 -0700 (Wed, 27 Jun 2007) $
+#   $Author: thaljef $
+# $Revision: 1709 $
+##############################################################################
+
 package Perl::Critic::Policy::ValuesAndExpressions::ProhibitLongChainsOfMethodCalls;
 
-use 5.006001;
 use strict;
 use warnings;
-use Readonly;
 
 use Perl::Critic::Utils qw{ :characters :severities };
-use Perl::Critic::Utils::PPI qw{ is_ppi_expression_or_generic_statement };
-
+use Perl::Critic::Utils::PPI qw{ &is_ppi_expression_or_generic_statement };
 use base 'Perl::Critic::Policy';
 
-our $VERSION = '1.139_01';
+our $VERSION = 1.06;
 
 #-----------------------------------------------------------------------------
 
-Readonly::Scalar my $EXPL =>
+my $EXPL =
     q{Long chains of method calls indicate code that is too tightly coupled};
 
 #-----------------------------------------------------------------------------
 
+my $DEFAULT_MAX_CHAIN_LENGTH = 3;
+
 sub supported_parameters {
-    return (
-        {
-            name            => 'max_chain_length',
-            description     => 'The number of chained calls to allow.',
-            default_string  => '3',
-            behavior        => 'integer',
-            integer_minimum => 1,
-        },
-    );
+    return qw{ max_chain_length };
 }
 
 sub default_severity { return $SEVERITY_LOW          }
@@ -37,6 +35,28 @@ sub applies_to       { return qw{ PPI::Statement };  }
 
 #-----------------------------------------------------------------------------
 
+sub new {
+    my $class = shift;
+    my $self = $class->SUPER::new(@_);
+
+    my (%config) = @_;
+
+    my $max_chain_length = $config{max_chain_length};
+    if (
+            not $max_chain_length
+        or  $max_chain_length !~ m/ \A \d+ \z /xms
+        or  $max_chain_length < 1
+    ) {
+        $max_chain_length = $DEFAULT_MAX_CHAIN_LENGTH;
+    }
+
+    $self->{_max_chain_length} = $max_chain_length;
+
+    return $self;
+}
+
+#-----------------------------------------------------------------------------
+
 sub _max_chain_length {
     my ( $self ) = @_;
 
@@ -70,16 +90,13 @@ sub violates {
                 $child->isa('PPI::Token::Word')
             or  $child->isa('PPI::Token::Symbol')
         ) {
-            if ( @children ) {
-                if ( $children[0]->isa('PPI::Token::Operator') ) {
-                    if ( q{->} eq $children[0]->content() ) {
-                        $chain_length++;
-                        shift @children;
-                    }
-                }
-                elsif ( not  $children[0]->isa('PPI::Token::Structure') ) {
-                    $chain_length = 0;
-                }
+            if (
+                    @children
+                and $children[0]->isa('PPI::Token::Operator')
+                and q{->} eq $children[0]->content()
+            ) {
+                $chain_length++;
+                shift @children;
             }
         }
         else {
@@ -123,13 +140,7 @@ __END__
 
 =head1 NAME
 
-Perl::Critic::Policy::ValuesAndExpressions::ProhibitLongChainsOfMethodCalls - Long chains of method calls indicate tightly coupled code.
-
-
-=head1 AFFILIATION
-
-This Policy is part of the core L<Perl::Critic|Perl::Critic>
-distribution.
+Perl::Critic::Policy::ValuesAndExpressions::ProhibitLongChainsOfMethodCalls
 
 
 =head1 DESCRIPTION
@@ -142,10 +153,10 @@ modified to deal with the change.  The code is too tightly coupled and
 is brittle.
 
 
-    $x = $y->a;           #ok
-    $x = $y->a->b;        #ok
-    $x = $y->a->b->c;     #questionable, but allowed by default
-    $x = $y->a->b->c->d;  #not ok
+  $x = $y->a;           #ok
+  $x = $y->a->b;        #ok
+  $x = $y->a->b->c;     #questionable, but allowed by default
+  $x = $y->a->b->c->d;  #not ok
 
 
 =head1 CONFIGURATION
@@ -154,18 +165,6 @@ This policy has one option: C<max_chain_length> which controls how far
 the code is allowed to navigate.  The default value is 3.
 
 
-=head1 TO DO
-
-Add a C<class_method_exemptions> option to allow for things like
-
-    File::Find::Rule
-        ->name('*.blah')
-        ->not_name('thingy')
-        ->readable()
-        ->directory()
-        ->in(@roots);
-
-
 =head1 AUTHOR
 
 Elliot Shank C<< <perl@galumph.com> >>
@@ -173,7 +172,7 @@ Elliot Shank C<< <perl@galumph.com> >>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2007-2011 Elliot Shank.
+Copyright (c) 2007 Elliot Shank.  All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.  The full text of this license
@@ -188,4 +187,4 @@ can be found in the LICENSE file included with this module.
 #   indent-tabs-mode: nil
 #   c-indentation-style: bsd
 # End:
-# ex: set ts=8 sts=4 sw=4 tw=78 ft=perl expandtab shiftround :
+# ex: set ts=8 sts=4 sw=4 tw=78 ft=perl expandtab :
