@@ -1,8 +1,8 @@
 ##############################################################################
-#      $URL: http://perlcritic.tigris.org/svn/perlcritic/tags/Perl-Critic-1.053/lib/Perl/Critic/Policy/ValuesAndExpressions/ProhibitMixedBooleanOperators.pm $
-#     $Date: 2007-06-03 13:16:10 -0700 (Sun, 03 Jun 2007) $
+#      $URL: http://perlcritic.tigris.org/svn/perlcritic/tags/Perl-Critic-1.06/lib/Perl/Critic/Policy/ValuesAndExpressions/ProhibitMixedBooleanOperators.pm $
+#     $Date: 2007-06-27 23:50:20 -0700 (Wed, 27 Jun 2007) $
 #   $Author: thaljef $
-# $Revision: 1578 $
+# $Revision: 1709 $
 ##############################################################################
 
 package Perl::Critic::Policy::ValuesAndExpressions::ProhibitMixedBooleanOperators;
@@ -12,26 +12,29 @@ use warnings;
 use Perl::Critic::Utils qw{ :severities :data_conversion };
 use base 'Perl::Critic::Policy';
 
-our $VERSION = 1.053;
 
 #-----------------------------------------------------------------------------
 
-my @low_booleans  = qw( not or and );
-my %low_booleans  = hashify( @low_booleans );
+our $VERSION = 1.06;
 
-my @high_booleans = qw( ! || && );
-my %high_booleans = hashify( @high_booleans );
+#-----------------------------------------------------------------------------
 
-my @exempt_types = qw(
-    PPI::Statement::Block
-    PPI::Statement::Scheduled
-    PPI::Statement::Package
-    PPI::Statement::Include
-    PPI::Statement::Sub
-    PPI::Statement::Variable
-    PPI::Statement::Compound
-    PPI::Statement::Data
-    PPI::Statement::End
+my %low_booleans  = hashify( qw( not or and ) );
+
+my %high_booleans = hashify( qw( ! || && ) );
+
+my %exempt_types = hashify(
+    qw(
+        PPI::Statement::Block
+        PPI::Statement::Scheduled
+        PPI::Statement::Package
+        PPI::Statement::Include
+        PPI::Statement::Sub
+        PPI::Statement::Variable
+        PPI::Statement::Compound
+        PPI::Statement::Data
+        PPI::Statement::End
+    )
 );
 
 #-----------------------------------------------------------------------------
@@ -41,10 +44,10 @@ my $expl = [ 70 ];
 
 #-----------------------------------------------------------------------------
 
-sub supported_parameters { return() }
-sub default_severity { return $SEVERITY_HIGH   }
-sub default_themes    { return qw( core bugs pbp )  }
-sub applies_to       { return 'PPI::Statement' }
+sub supported_parameters { return                     }
+sub default_severity     { return $SEVERITY_HIGH      }
+sub default_themes       { return qw( core bugs pbp ) }
+sub applies_to           { return 'PPI::Statement'    }
 
 #-----------------------------------------------------------------------------
 
@@ -58,10 +61,7 @@ sub violates {
     # better ways to do this, such as scanning for a semi-colon or
     # some other marker.
 
-    for my $type (@exempt_types) {
-        return if $elem->isa($type);
-    }
-
+    return if exists $exempt_types{ ref $elem };
 
     if (    $elem->find_first(\&_low_boolean)
          && $elem->find_first(\&_high_boolean) ) {
@@ -71,6 +71,7 @@ sub violates {
     return;    #ok!
 }
 
+#-----------------------------------------------------------------------------
 
 sub _low_boolean {
     my (undef, $elem) = @_;
@@ -78,6 +79,8 @@ sub _low_boolean {
     return exists $low_booleans{$elem};
 }
 
+#-----------------------------------------------------------------------------
+
 sub _high_boolean {
     my (undef, $elem) = @_;
     $elem->isa('PPI::Token::Operator') || return 0;
