@@ -1,31 +1,35 @@
+##############################################################################
+#      $URL: http://perlcritic.tigris.org/svn/perlcritic/tags/Perl-Critic-1.06/lib/Perl/Critic/Policy/ValuesAndExpressions/ProhibitQuotesAsQuotelikeOperatorDelimiters.pm $
+#     $Date: 2007-06-27 23:50:20 -0700 (Wed, 27 Jun 2007) $
+#   $Author: thaljef $
+# $Revision: 1709 $
+##############################################################################
+
 package Perl::Critic::Policy::ValuesAndExpressions::ProhibitQuotesAsQuotelikeOperatorDelimiters;
 
-use 5.006001;
 use strict;
 use warnings;
-use Readonly;
 
-use Perl::Critic::Utils qw{
-    :booleans :characters :severities :data_conversion
-};
+use Perl::Critic::Utils qw{ :characters :severities :data_conversion };
+
 use base 'Perl::Critic::Policy';
 
-our $VERSION = '1.139_01';
+our $VERSION = 1.06;
 
 #-----------------------------------------------------------------------------
 
-Readonly::Hash my %DESCRIPTIONS => (
+my %DESCRIPTIONS = (
     $QUOTE    => q{Single-quote used as quote-like operator delimiter},
     $DQUOTE   => q{Double-quote used as quote-like operator delimiter},
     $BACKTICK => q{Back-quote (back-tick) used as quote-like operator delimiter},
 );
 
-Readonly::Scalar my $EXPL =>
+my $EXPL        =
     q{Using quotes as delimiters for quote-like operators obfuscates code};
 
-Readonly::Array my @OPERATORS => qw{ m q qq qr qw qx s tr y };
+my %OPERATORS = hashify( qw{ m q qq qr qw qx s tr y } );
 
-Readonly::Hash my %INFO_RETRIEVERS_BY_PPI_CLASS => (
+my %INFO_RETRIEVERS_BY_PPI_CLASS = (
     'PPI::Token::Quote::Literal'        => \&_info_for_single_character_operator,
     'PPI::Token::Quote::Interpolate'    => \&_info_for_two_character_operator,
     'PPI::Token::QuoteLike::Command'    => \&_info_for_two_character_operator,
@@ -39,35 +43,11 @@ Readonly::Hash my %INFO_RETRIEVERS_BY_PPI_CLASS => (
 #-----------------------------------------------------------------------------
 
 sub supported_parameters {
-    return (
-        {
-            name               => 'single_quote_allowed_operators',
-            description        =>
-                'The operators to allow single-quotes as delimiters for.',
-            default_string     => 'm s qr qx',
-            behavior           => 'enumeration',
-            enumeration_values => [ @OPERATORS ],
-            enumeration_allow_multiple_values => 1,
-        },
-        {
-            name               => 'double_quote_allowed_operators',
-            description        =>
-                'The operators to allow double-quotes as delimiters for.',
-            default_string     => $EMPTY,
-            behavior           => 'enumeration',
-            enumeration_values => [ @OPERATORS ],
-            enumeration_allow_multiple_values => 1,
-        },
-        {
-            name               => 'back_quote_allowed_operators',
-            description        =>
-                'The operators to allow back-quotes (back-ticks) as delimiters for.',
-            default_string     => $EMPTY,
-            behavior           => 'enumeration',
-            enumeration_values => [ @OPERATORS ],
-            enumeration_allow_multiple_values => 1,
-        },
-    );
+    return qw{
+        single_quote_allowed_operators
+        double_quote_allowed_operators
+        back_quote_allowed_operators
+    };
 }
 
 sub default_severity { return $SEVERITY_MEDIUM       }
@@ -88,8 +68,27 @@ sub applies_to {
 
 #-----------------------------------------------------------------------------
 
-sub initialize_if_enabled {
-    my ($self, $config) = @_;
+sub new {
+    my $class = shift;
+    my $self = $class->SUPER::new(@_);
+
+    my (%config) = @_;
+
+    $self->_parse_parameter(
+        'single_quote_allowed_operators',
+        \%config,
+        'm s qr qx'
+    );
+    $self->_parse_parameter(
+        'double_quote_allowed_operators',
+        \%config,
+        $EMPTY
+    );
+    $self->_parse_parameter(
+        'back_quote_allowed_operators',
+        \%config,
+        $EMPTY
+    );
 
     $self->{_allowed_operators_by_delimiter} = {
         $QUOTE    => $self->_single_quote_allowed_operators(),
@@ -97,7 +96,7 @@ sub initialize_if_enabled {
         $BACKTICK => $self->_back_quote_allowed_operators(),
     };
 
-    return $TRUE;
+    return $self;
 }
 
 #-----------------------------------------------------------------------------
@@ -128,6 +127,32 @@ sub _allowed_operators_by_delimiter {
 
 #-----------------------------------------------------------------------------
 
+sub _parse_parameter {
+    my ( $self, $parameter_name, $config, $default_value ) = @_;
+
+    my @potential_values;
+    my $value_string = $default_value;
+    my $parameter_value = $config->{$parameter_name};
+
+    if (defined $parameter_value) {
+        $value_string = $parameter_value;
+    }
+
+    if ( defined $value_string ) {
+        @potential_values = words_from_string($value_string);
+
+        @potential_values = grep { exists $OPERATORS{$_} } @potential_values;
+    }
+
+    my %actual_values = hashify( @potential_values );
+
+    $self->{"_$parameter_name"} = \%actual_values;
+
+    return;
+}
+
+#-----------------------------------------------------------------------------
+
 sub violates {
     my ( $self, $elem, undef ) = @_;
 
@@ -200,17 +225,11 @@ __END__
 
 =pod
 
-=for stopwords Schwern
+=for stopwords MSCHWERN
 
 =head1 NAME
 
-Perl::Critic::Policy::ValuesAndExpressions::ProhibitQuotesAsQuotelikeOperatorDelimiters - Don't use quotes (C<'>, C<">, C<`>) as delimiters for the quote-like operators.
-
-
-=head1 AFFILIATION
-
-This Policy is part of the core L<Perl::Critic|Perl::Critic>
-distribution.
+Perl::Critic::Policy::ValuesAndExpressions::ProhibitQuotesAsQuotelikeOperatorDelimiters
 
 
 =head1 DESCRIPTION
@@ -220,25 +239,25 @@ interpolation, using quotes with the quote-like operators kind of
 defeats the purpose of them and produces obfuscated code, causing
 problems for future maintainers and their editors/IDEs.
 
-    $x = q"q";                #not ok
-    $x = q'q';                #not ok
-    $x = q`q`;                #not ok
+  $x = q"q";                #not ok
+  $x = q'q';                #not ok
+  $x = q`q`;                #not ok
 
-    $x = qq"q";               #not ok
-    $x = qr"r";               #not ok
-    $x = qw"w";               #not ok
+  $x = qq"q";               #not ok
+  $x = qr"r";               #not ok
+  $x = qw"w";               #not ok
 
-    $x = qx`date`;            #not ok
+  $x = qx`date`;            #not ok
 
-    $x =~ m"m";               #not ok
-    $x =~ s"s"x";             #not ok
-    $x =~ tr"t"r";            #not ok
-    $x =~ y"x"y";             #not ok
+  $x =~ m"m";               #not ok
+  $x =~ s"s"x";             #not ok
+  $x =~ tr"t"r";            #not ok
+  $x =~ y"x"y";             #not ok
 
-    $x =~ m'$x';              #ok
-    $x =~ s'$x'y';            #ok
-    $x = qr'$x'm;             #ok
-    $x = qx'finger foo@bar';  #ok
+  $x =~ m'$x';              #ok
+  $x =~ s'$x'y';            #ok
+  $x = qr'$x'm;             #ok
+  $x = qx'finger foo@bar';  #ok
 
 
 =head1 CONFIGURATION
@@ -258,15 +277,15 @@ delimiters for the C<m>, C<qr>, C<qx>, and C<s> operators.  These
 defaults are equivalent to having the following in your
 F<.perlcriticrc>:
 
-    [ValuesAndExpressions::ProhibitQuotesAsQuotelikeOperatorDelimiters]
-    single_quote_allowed_operators = m s qr qx
-    double_quote_allowed_operators =
-    back_quote_allowed_operators =
+  [ValuesAndExpressions::ProhibitQuotesAsQuotelikeOperatorDelimiters]
+  single_quote_allowed_operators = m s qr qx
+  double_quote_allowed_operators =
+  back_quote_allowed_operators =
 
 
 =head1 SUGGESTED BY
 
-Michael Schwern
+MSCHWERN
 
 
 =head1 AUTHOR
@@ -276,7 +295,7 @@ Elliot Shank C<< <perl@galumph.com> >>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2007-2011 Elliot Shank.
+Copyright (c) 2007 Elliot Shank.  All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.  The full text of this license
@@ -291,4 +310,4 @@ can be found in the LICENSE file included with this module.
 #   indent-tabs-mode: nil
 #   c-indentation-style: bsd
 # End:
-# ex: set ts=8 sts=4 sw=4 tw=78 ft=perl expandtab shiftround :
+# ex: set ts=8 sts=4 sw=4 tw=78 ft=perl expandtab :
