@@ -1,8 +1,8 @@
 ##############################################################################
-#      $URL: http://perlcritic.tigris.org/svn/perlcritic/tags/Perl-Critic-1.053/lib/Perl/Critic/Utils/McCabe.pm $
-#     $Date: 2007-06-03 13:16:10 -0700 (Sun, 03 Jun 2007) $
+#      $URL: http://perlcritic.tigris.org/svn/perlcritic/tags/Perl-Critic-1.06/lib/Perl/Critic/Utils/McCabe.pm $
+#     $Date: 2007-06-27 23:50:20 -0700 (Wed, 27 Jun 2007) $
 #   $Author: thaljef $
-# $Revision: 1578 $
+# $Revision: 1709 $
 ##############################################################################
 
 package Perl::Critic::Utils::McCabe;
@@ -10,27 +10,30 @@ package Perl::Critic::Utils::McCabe;
 use strict;
 use warnings;
 
-use Perl::Critic::Utils qw{ :data_conversion :classification };
+use Perl::Critic::Utils qw{ &hashify &is_hash_key };
 
 use base 'Exporter';
 
-our $VERSION = 1.053;
+#-----------------------------------------------------------------------------
+
+our $VERSION = 1.06;
 
 #-----------------------------------------------------------------------------
 
-our @EXPORT_OK = qw( &calculate_mccabe_of_sub );
+our @EXPORT_OK =
+  qw( &calculate_mccabe_of_sub &calculate_mccabe_of_main );
 
 #-----------------------------------------------------------------------------
 
-my @logic_ops = qw( && || ||= &&= or and xor ? <<= >>= );
-my %logic_ops = hashify( @logic_ops );
+my %LOGIC_OPS = hashify( qw( && || ||= &&= or and xor ? <<= >>= ) );
 
-my @logic_keywords = qw( if else elsif unless until while for foreach );
-my %logic_keywords = hashify( @logic_keywords );
+my %LOGIC_KEYWORDS =
+    hashify( qw( if else elsif unless until while for foreach ) );
 
 #-----------------------------------------------------------------------------
 
 sub calculate_mccabe_of_sub {
+
     my ( $sub ) = @_;
 
     my $count = 1; # Minimum score is 1
@@ -42,14 +45,68 @@ sub calculate_mccabe_of_sub {
 
 #-----------------------------------------------------------------------------
 
+sub calculate_mccabe_of_main {
+
+    my ( $doc ) = @_;
+
+    my $count = 1; # Minimum score is 1
+    $count += _count_main_logic_operators_and_keywords( $doc );
+    return $count;
+}
+
+#-----------------------------------------------------------------------------
+
+sub _count_main_logic_operators_and_keywords {
+
+    my ( $doc ) = @_;
+
+    # I can't leverage Perl::Critic::Document's fast search mechanism here
+    # because we're not searching for elements by class name.  So to speed
+    # things up, search for both keywords and operators at the same time.
+
+    my $wanted = sub {
+
+        my (undef, $elem) = @_;
+
+        # Only count things that *are not* in a subroutine.  Returning an
+        # explicit 'undef' here prevents PPI from descending into the node.
+
+        ## no critic Subroutines::ProhibitExplicitReturnUndef
+        return undef if $elem->isa('PPI::Statement::Sub');
+
+
+        if ( $elem->isa('PPI::Token::Word') ) {
+            return 0 if is_hash_key( $elem );
+            return exists $LOGIC_KEYWORDS{$elem};
+        }
+        elsif ($elem->isa('PPI::Token::Operator') ) {
+            return exists $LOGIC_OPS{$elem};
+        }
+    };
+
+    my $logic_operators_and_keywords = $doc->find( $wanted );
+
+    my $count = $logic_operators_and_keywords ?
+      scalar @{$logic_operators_and_keywords} : 0;
+
+    return $count;
+}
+
+#-----------------------------------------------------------------------------
+
 sub _count_logic_keywords {
-    my $sub = shift;
+
+    my ( $sub ) = @_;
     my $count = 0;
 
+    # Here, I'm using this round-about method of finding elements so
+    # that I can take advantage of Perl::Critic::Document's faster
+    # find() mechanism.  It can only search for elements by class name.
+
     my $keywords_ref = $sub->find('PPI::Token::Word');
     if ( $keywords_ref ) { # should always be true due to "sub" keyword
         my @filtered = grep { ! is_hash_key($_) } @{ $keywords_ref };
-        $count = grep { exists $logic_keywords{$_} } @filtered;
+        $count = grep { exists $LOGIC_KEYWORDS{$_} } @filtered;
     }
     return $count;
 }
@@ -57,12 +114,17 @@ sub _count_logic_keywords {
 #-----------------------------------------------------------------------------
 
 sub _count_logic_operators {
-    my $sub = shift;
+
+    my ( $sub ) = @_;
     my $count = 0;
 
+    # Here, I'm using this round-about method of finding elements so
+    # that I can take advantage of Perl::Critic::Document's faster
+    # find() mechanism.  It can only search for elements by class name.
+
     my $operators_ref = $sub->find('PPI::Token::Operator');
     if ( $operators_ref ) {
-        $count = grep { exists $logic_ops{$_} }  @{ $operators_ref };
+        $count = grep { exists $LOGIC_OPS{$_} }  @{ $operators_ref };
     }
 
     return $count;
@@ -102,6 +164,11 @@ some discussion about the McCabe number and other complexity metrics.
 Calculates an approximation of the McCabe number of the code in a
 L<PPI::Statement::Sub>.
 
+=item C<calculate_mccabe_of_main( $doc )>
+
+Calculates an approximation of the McCabe number of all the code in a
+L<PPI::Statement::Document> that is B<not> contained in a subroutine.
+
 =back
 
 
